venim package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   venim.akatsuki

Submodules
----------

venim.cleaning module
---------------------

.. automodule:: venim.cleaning
   :members:
   :undoc-members:
   :show-inheritance:

venim.config module
-------------------

.. automodule:: venim.config
   :members:
   :undoc-members:
   :show-inheritance:

venim.fits\_cli module
----------------------

.. automodule:: venim.fits_cli
   :members:
   :undoc-members:
   :show-inheritance:

venim.image module
------------------

.. automodule:: venim.image
   :members:
   :undoc-members:
   :show-inheritance:

venim.mask\_functions module
----------------------------

.. automodule:: venim.mask_functions
   :members:
   :undoc-members:
   :show-inheritance:

venim.pathmanager module
------------------------

.. automodule:: venim.pathmanager
   :members:
   :undoc-members:
   :show-inheritance:

venim.stats module
------------------

.. automodule:: venim.stats
   :members:
   :undoc-members:
   :show-inheritance:

venim.utils module
------------------

.. automodule:: venim.utils
   :members:
   :undoc-members:
   :show-inheritance:

venim.venim module
------------------

.. automodule:: venim.venim
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: venim
   :members:
   :undoc-members:
   :show-inheritance:
